@@ -45,14 +45,14 @@ class SurfacePointCloud:
             distances[inside] *= -1
             return distances
 
-    def get_sdf_in_batches(self, query_points, use_depth_buffer=False, sample_count=11, batch_size=1e6):
+    def get_sdf_in_batches(self, query_points, use_depth_buffer=False, sample_count=11, batch_size=1000000):
         if query_points.shape[0] <= batch_size:
             return self.get_sdf(query_points, use_depth_buffer=use_depth_buffer, sample_count=sample_count)
         
         result = np.zeros(query_points.shape[0])
         for i in range(int(math.ceil(query_points.shape[0] / batch_size))):
-            start = i * batch_size
-            end = min(result.shape[0], (i + 1) * batch_size)
+            start = int(i * batch_size)
+            end = int(min(result.shape[0], (i + 1) * batch_size))
             result[start:end] = self.get_sdf(query_points[start:end, :], use_depth_buffer=use_depth_buffer, sample_count=sample_count)
         return result
 
@@ -77,7 +77,7 @@ class SurfacePointCloud:
         query_points.append(surface_points + np.random.normal(scale=0.0025, size=(surface_sample_count, 3)))
         query_points.append(surface_points + np.random.normal(scale=0.00025, size=(surface_sample_count, 3)))
 
-        unit_sphere_sample_count = number_of_points - surface_sample_count
+        unit_sphere_sample_count = number_of_points - surface_sample_count * 2
         unit_sphere_points = np.random.uniform(-1, 1, size=(unit_sphere_sample_count * 2, 3))
         unit_sphere_points = unit_sphere_points[np.linalg.norm(unit_sphere_points, axis=1) < 1]
         query_points.append(unit_sphere_points[:unit_sphere_sample_count, :])
@@ -86,7 +86,7 @@ class SurfacePointCloud:
         if sign_method == 'normal':
             sdf = self.get_sdf_in_batches(query_points, use_depth_buffer=False, sample_count=normal_sample_count)
         elif sign_method == 'depth':
-            sdf = surface_point_cloud.get_sdf_in_batches(query_points, use_depth_buffer=True)
+            sdf = self.get_sdf_in_batches(query_points, use_depth_buffer=True)
         else:
             raise ValueError('Unknown sign determination method: {:s}'.format(sign_method))
         
@@ -147,4 +147,4 @@ def sample_from_mesh(mesh, sample_point_count=10000000, calculate_normals=True):
         points=points,
         normals=normals if calculate_normals else None,
         scans=None
-    )
\ No newline at end of file
+    )
